@@ -51,13 +51,16 @@ long kt_state(void *ktask)
 	return (long)((struct task_struct*)ktask)->state;
 }
 
-void * kt_esp(void *ktask)
+void * kt_stack(void *ktask)
 {
+#ifdef CONFIG_X86
+#ifdef CONFIG_64BIT
+	return (void*)((struct task_struct*)ktask)->thread.rsp;
+#else
 	return (void*)((struct task_struct*)ktask)->thread.esp;
-}
-
-void * kt_esp0(void *ktask)
-{
-	return (void*)((struct task_struct*)ktask)->thread.esp0;
+#endif
+#else
+	return NULL;
+#endif
 }
 
